@@ -38,10 +38,10 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_version =
-        "17.0.1";
+        "18.0.1.1";
 
     private static final String java_version_date =
-        "2021-10-19";
+        "2022-04-22";
 
     // This field is read by HotSpot
     private static final String java_runtime_name =
@@ -49,16 +49,16 @@ class VersionProps {
 
     // This field is read by HotSpot
     private static final String java_runtime_version =
-        "17.0.1+12";
+        "18.0.1.1+2";
 
     private static final String VERSION_NUMBER =
-        "17.0.1";
+        "18.0.1.1";
 
     private static final String VERSION_SPECIFICATION =
-        "17";
+        "18";
 
     private static final String VERSION_BUILD =
-        "12";
+        "2";
 
     private static final String VERSION_PRE =
         "";
@@ -70,7 +70,7 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "61.0";
+        "62.0";
 
     private static final String VENDOR =
         "N/A";
