@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2014, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,34 +24,33 @@
  */
 package jdk.jshell;
 
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.List;
-import java.util.Locale;
+import java.util.*;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import java.util.stream.Collectors;
 import javax.lang.model.element.Modifier;
+import javax.lang.model.element.Name;
+
 import com.sun.source.tree.ArrayTypeTree;
 import com.sun.source.tree.AssignmentTree;
 import com.sun.source.tree.ClassTree;
+import com.sun.source.tree.CompilationUnitTree;
 import com.sun.source.tree.ExpressionStatementTree;
 import com.sun.source.tree.ExpressionTree;
 import com.sun.source.tree.IdentifierTree;
+import com.sun.source.tree.MethodInvocationTree;
 import com.sun.source.tree.MethodTree;
 import com.sun.source.tree.ModifiersTree;
 import com.sun.source.tree.NewClassTree;
 import com.sun.source.tree.Tree;
 import com.sun.source.tree.VariableTree;
+import com.sun.source.util.TreePathScanner;
 import com.sun.tools.javac.tree.JCTree;
 import com.sun.tools.javac.tree.Pretty;
 import java.io.IOException;
 import java.io.StringWriter;
 import java.io.Writer;
-import java.util.Arrays;
-import java.util.LinkedHashSet;
-import java.util.Set;
+
 import jdk.jshell.ExpressionToTypeInfo.ExpressionInfo;
 import jdk.jshell.ExpressionToTypeInfo.ExpressionInfo.AnonymousDescription;
 import jdk.jshell.ExpressionToTypeInfo.ExpressionInfo.AnonymousDescription.VariableDesc;
@@ -75,11 +74,12 @@ import jdk.jshell.spi.ExecutionControl.NotImplementedException;
 import jdk.jshell.spi.ExecutionControl.ResolutionException;
 import jdk.jshell.spi.ExecutionControl.RunException;
 import jdk.jshell.spi.ExecutionControl.UserException;
-import static java.util.stream.Collectors.toList;
 import static java.util.stream.Collectors.toSet;
 import static java.util.Collections.singletonList;
 import com.sun.tools.javac.code.Symbol.TypeSymbol;
 import static jdk.internal.jshell.debug.InternalDebugControl.DBG_GEN;
+import static jdk.jshell.Snippet.Status.RECOVERABLE_DEFINED;
+import static jdk.jshell.Snippet.Status.VALID;
 import static jdk.jshell.Util.DOIT_METHOD_NAME;
 import static jdk.jshell.Util.PREFIX_PATTERN;
 import static jdk.jshell.Util.expunge;
@@ -214,30 +214,28 @@ class Eval {
             String compileSourceInt = new MaskCommentsAndModifiers(compileSource, true).cleared();
 
             state.debug(DBG_GEN, "Kind: %s -- %s\n", unitTree.getKind(), unitTree);
-            switch (unitTree.getKind()) {
-                case IMPORT:
-                    return processImport(userSource, compileSourceInt);
-                case VARIABLE:
-                    return processVariables(userSource, units, compileSourceInt, pt);
-                case EXPRESSION_STATEMENT:
-                    return processExpression(userSource, unitTree, compileSourceInt, pt);
-                case CLASS:
-                    return processClass(userSource, unitTree, compileSourceInt, SubKind.CLASS_SUBKIND, pt);
-                case ENUM:
-                    return processClass(userSource, unitTree, compileSourceInt, SubKind.ENUM_SUBKIND, pt);
-                case ANNOTATION_TYPE:
-                    return processClass(userSource, unitTree, compileSourceInt, SubKind.ANNOTATION_TYPE_SUBKIND, pt);
-                case INTERFACE:
-                    return processClass(userSource, unitTree, compileSourceInt, SubKind.INTERFACE_SUBKIND, pt);
-                case RECORD:
-                    @SuppressWarnings("preview")
-                    List<Snippet> snippets = processClass(userSource, unitTree, compileSourceInt, SubKind.RECORD_SUBKIND, pt);
-                    return snippets;
-                case METHOD:
-                    return processMethod(userSource, unitTree, compileSourceInt, pt);
-                default:
-                    return processStatement(userSource, compileSourceInt);
-            }
+            return switch (unitTree.getKind()) {
+                case IMPORT
+                    -> processImport(userSource, compileSourceInt);
+                case VARIABLE
+                    -> processVariables(userSource, units, compileSourceInt, pt);
+                case EXPRESSION_STATEMENT
+                    -> processExpression(userSource, unitTree, compileSourceInt, pt);
+                case CLASS
+                    -> processClass(userSource, unitTree, compileSourceInt, SubKind.CLASS_SUBKIND, pt);
+                case ENUM
+                    -> processClass(userSource, unitTree, compileSourceInt, SubKind.ENUM_SUBKIND, pt);
+                case ANNOTATION_TYPE
+                    -> processClass(userSource, unitTree, compileSourceInt, SubKind.ANNOTATION_TYPE_SUBKIND, pt);
+                case INTERFACE
+                    -> processClass(userSource, unitTree, compileSourceInt, SubKind.INTERFACE_SUBKIND, pt);
+                case RECORD
+                    -> processClass(userSource, unitTree, compileSourceInt, SubKind.RECORD_SUBKIND, pt);
+                case METHOD
+                    -> processMethod(userSource, unitTree, compileSourceInt, pt);
+                default
+                    -> processStatement(userSource, compileSourceInt);
+            };
         });
     }
 
@@ -304,6 +302,7 @@ class Eval {
         for (Tree unitTree : units) {
             VariableTree vt = (VariableTree) unitTree;
             String name = vt.getName().toString();
+//            String name = userReadableName(vt.getName(), compileSource);
             String typeName;
             String fullTypeName;
             String displayType;
@@ -371,42 +370,32 @@ class Eval {
                 winit = winit == null ? Wrap.rangeWrap(compileSource, rinit) : winit;
                 nameMax = rinit.begin - 1;
             } else {
-                String sinit;
-                switch (typeName) {
-                    case "byte":
-                    case "short":
-                    case "int":
-                        sinit = "0";
-                        break;
-                    case "long":
-                        sinit = "0L";
-                        break;
-                    case "float":
-                        sinit = "0.0f";
-                        break;
-                    case "double":
-                        sinit = "0.0d";
-                        break;
-                    case "boolean":
-                        sinit = "false";
-                        break;
-                    case "char":
-                        sinit = "'\\u0000'";
-                        break;
-                    default:
-                        sinit = "null";
-                        break;
-                }
+                String sinit = switch (typeName) {
+                    case "byte",
+                         "short",
+                         "int"     -> "0";
+                    case "long"    -> "0L";
+                    case "float"   -> "0.0f";
+                    case "double"  -> "0.0d";
+                    case "boolean" -> "false";
+                    case "char"    -> "'\\u0000'";
+                    default        -> "null";
+                };
                 winit = Wrap.simpleWrap(sinit);
                 subkind = SubKind.VAR_DECLARATION_SUBKIND;
             }
+            Wrap wname;
             int nameStart = compileSource.lastIndexOf(name, nameMax);
             if (nameStart < 0) {
-                throw new AssertionError("Name '" + name + "' not found");
+                // the name has been transformed (e.g. unicode).
+                // Use it directly
+                wname = Wrap.identityWrap(name);
+            } else {
+                int nameEnd = nameStart + name.length();
+                Range rname = new Range(nameStart, nameEnd);
+                wname = new Wrap.RangeWrap(compileSource, rname);
             }
-            int nameEnd = nameStart + name.length();
-            Range rname = new Range(nameStart, nameEnd);
-            Wrap guts = Wrap.varWrap(compileSource, typeWrap, sbBrackets.toString(), rname,
+            Wrap guts = Wrap.varWrap(compileSource, typeWrap, sbBrackets.toString(), wname,
                                      winit, enhancedDesugaring, anonDeclareWrap);
             DiagList modDiag = modifierDiagnostics(vt.getModifiers(), dis, true);
             Snippet snip = new VarSnippet(state.keyMap.keyForVariable(name), userSource, guts,
@@ -417,6 +406,26 @@ class Eval {
         return snippets;
     }
 
+    private String userReadableName(Name nn, String compileSource) {
+        String s = nn.toString();
+        if (s.length() > 0 && Character.isJavaIdentifierStart(s.charAt(0)) && compileSource.contains(s)) {
+            return s;
+        }
+        String l = nameInUnicode(nn, false);
+        if (compileSource.contains(l)) {
+            return l;
+        }
+        return nameInUnicode(nn, true);
+    }
+
+    private String nameInUnicode(Name nn, boolean upper) {
+        return nn.codePoints()
+                .mapToObj(cp -> (cp > 0x7F)
+                        ? String.format(upper ? "\\u%04X" : "\\u%04x", cp)
+                        : "" + (char) cp)
+                .collect(Collectors.joining());
+    }
+
     /**Convert anonymous classes in "init" to member classes, based
      * on the additional information from ExpressionInfo.anonymousClasses.
      *
@@ -660,6 +669,10 @@ class Eval {
             if (ei == null) {
                 // We got no type info, check for not a statement by trying
                 DiagList dl = trialCompile(guts);
+                if (dl.hasUnreachableError()) {
+                    guts = Wrap.methodUnreachableWrap(compileSource);
+                    dl = trialCompile(guts);
+                }
                 if (dl.hasNotStatement()) {
                     guts = Wrap.methodReturnWrap(compileSource);
                     dl = trialCompile(guts);
@@ -680,6 +693,7 @@ class Eval {
         TreeDissector dis = TreeDissector.createByFirstClass(pt);
 
         ClassTree klassTree = (ClassTree) unitTree;
+//        String name = userReadableName(klassTree.getSimpleName(), compileSource);
         String name = klassTree.getSimpleName().toString();
         DiagList modDiag = modifierDiagnostics(klassTree.getModifiers(), dis, false);
         TypeDeclKey key = state.keyMap.keyForClass(name);
@@ -730,6 +744,7 @@ class Eval {
         final TreeDissector dis = TreeDissector.createByFirstClass(pt);
 
         final MethodTree mt = (MethodTree) unitTree;
+        //String name = userReadableName(mt.getName(), compileSource);
         final String name = mt.getName().toString();
         if (objectMethods.contains(name)) {
             // The name matches a method on Object, short of an overhaul, this
@@ -753,21 +768,40 @@ class Eval {
                 .map(param -> dis.treeToRange(param.getType()).part(compileSource))
                 .collect(Collectors.joining(","));
         Tree returnType = mt.getReturnType();
-        DiagList modDiag = modifierDiagnostics(mt.getModifiers(), dis, true);
-        MethodKey key = state.keyMap.keyForMethod(name, parameterTypes);
-        // Corralling
-        Wrap corralled = new Corraller(dis, key.index(), compileSource).corralMethod(mt);
-
+        DiagList modDiag = modifierDiagnostics(mt.getModifiers(), dis, false);
         if (modDiag.hasErrors()) {
             return compileFailResult(modDiag, userSource, Kind.METHOD);
         }
-        Wrap guts = Wrap.classMemberWrap(compileSource);
+        MethodKey key = state.keyMap.keyForMethod(name, parameterTypes);
+
+        Wrap corralled;
+        Wrap guts;
+        String unresolvedSelf;
+        if (mt.getModifiers().getFlags().contains(Modifier.ABSTRACT)) {
+            if (mt.getBody() == null) {
+                // abstract method -- pre-corral
+                corralled = null; // no fall-back
+                guts = new Corraller(dis, key.index(), compileSource).corralMethod(mt);
+                unresolvedSelf = "method " + name + "(" + parameterTypes + ")";
+            } else {
+                // abstract with body, don't pollute the error message
+                corralled = null;
+                guts = Wrap.simpleWrap(compileSource);
+                unresolvedSelf = null;
+            }
+        } else {
+            // normal method
+            corralled = new Corraller(dis, key.index(), compileSource).corralMethod(mt);
+            guts = Wrap.classMemberWrap(compileSource);
+            unresolvedSelf = null;
+        }
         Range typeRange = dis.treeToRange(returnType);
         String signature = "(" + parameterTypes + ")" + typeRange.part(compileSource);
 
         Snippet snip = new MethodSnippet(key, userSource, guts,
                 name, signature,
-                corralled, tds.declareReferences(), tds.bodyReferences(), modDiag);
+                corralled, tds.declareReferences(), tds.bodyReferences(),
+                unresolvedSelf, modDiag);
         return singletonList(snip);
     }
 
@@ -798,7 +832,7 @@ class Eval {
      * @param userSource the incoming bad user source
      * @return a rejected snippet
      */
-    private List<Snippet> compileFailResult(BaseTask xt, String userSource, Kind probableKind) {
+    private List<Snippet> compileFailResult(BaseTask<?> xt, String userSource, Kind probableKind) {
         return compileFailResult(xt.getDiagnostics(), userSource, probableKind);
     }
 
@@ -817,23 +851,14 @@ class Eval {
 
         // Install  wrapper for query by SourceCodeAnalysis.wrapper
         String compileSource = Util.trimEnd(new MaskCommentsAndModifiers(userSource, true).cleared());
-        OuterWrap outer;
-        switch (probableKind) {
-            case IMPORT:
-                outer = state.outerMap.wrapImport(Wrap.simpleWrap(compileSource), snip);
-                break;
-            case EXPRESSION:
-                outer = state.outerMap.wrapInTrialClass(Wrap.methodReturnWrap(compileSource));
-                break;
-            case VAR:
-            case TYPE_DECL:
-            case METHOD:
-                outer = state.outerMap.wrapInTrialClass(Wrap.classMemberWrap(compileSource));
-                break;
-            default:
-                outer = state.outerMap.wrapInTrialClass(Wrap.methodWrap(compileSource));
-                break;
-        }
+        OuterWrap outer = switch (probableKind) {
+            case IMPORT     -> state.outerMap.wrapImport(Wrap.simpleWrap(compileSource), snip);
+            case EXPRESSION -> state.outerMap.wrapInTrialClass(Wrap.methodReturnWrap(compileSource));
+            case VAR,
+                 TYPE_DECL,
+                 METHOD     -> state.outerMap.wrapInTrialClass(Wrap.classMemberWrap(compileSource));
+            default         -> state.outerMap.wrapInTrialClass(Wrap.methodWrap(compileSource));
+        };
         snip.setOuterWrap(outer);
 
         return singletonList(snip);
@@ -867,6 +892,18 @@ class Eval {
         ins.add(c);
         Set<Unit> outs = compileAndLoad(ins);
 
+        if (si.status().isActive() && si instanceof MethodSnippet) {
+            // special processing for abstract methods
+            MethodSnippet msi = (MethodSnippet) si;
+            String unresolvedSelf = msi.unresolvedSelf;
+            if (unresolvedSelf != null) {
+                List<String> unresolved = new ArrayList<>(si.unresolved());
+                unresolved.add(unresolvedSelf);
+                si.setCompilationStatus(si.status() == VALID ? RECOVERABLE_DEFINED : si.status(),
+                        unresolved, si.diagnostics());
+            }
+        }
+
         if (!si.status().isDefined()
                 && si.diagnostics().isEmpty()
                 && si.unresolved().isEmpty()) {
@@ -947,11 +984,11 @@ class Eval {
                 .filter(u -> u != c)
                 .map(u -> u.event(null, null))
                 .filter(this::interestingEvent)
-                .collect(Collectors.toList()));
+                .toList());
         events.addAll(outs.stream()
                 .flatMap(u -> u.secondaryEvents().stream())
                 .filter(this::interestingEvent)
-                .collect(Collectors.toList()));
+                .toList());
         //System.err.printf("Events: %s\n", events);
         return events;
     }
@@ -973,6 +1010,53 @@ class Eval {
 
             ins.stream().forEach(Unit::initialize);
             ins.stream().forEach(u -> u.setWrap(ins, ins));
+
+            if (ins.stream().anyMatch(u -> u.snippet().kind() == Kind.METHOD)) {
+                //if there is any method declaration, check the body of the method for
+                //invocations of a method of the same name. It may be an invocation of
+                //an overloaded method, in which case we need to add all the overloads to
+                //ins, so that they are processed together and can refer to each other:
+                Set<Unit> overloads = new LinkedHashSet<>();
+                Map<OuterWrap, Unit> outter2Unit = new LinkedHashMap<>();
+                ins.forEach(u -> outter2Unit.put(u.snippet().outerWrap(), u));
+
+                state.taskFactory.analyze(outter2Unit.keySet(), at -> {
+                    Set<Unit> suspiciousMethodInvocation = new LinkedHashSet<>();
+                    for (CompilationUnitTree cut : at.cuTrees()) {
+                        Unit unit = outter2Unit.get(at.sourceForFile(cut.getSourceFile()));
+                        String name = unit.snippet().name();
+
+                        new TreePathScanner<Void, Void>() {
+                            @Override
+                            public Void visitMethodInvocation(MethodInvocationTree node, Void p) {
+                                if (node.getMethodSelect().getKind() == Tree.Kind.IDENTIFIER &&
+                                    ((IdentifierTree) node.getMethodSelect()).getName().contentEquals(name)) {
+                                    suspiciousMethodInvocation.add(unit);
+                                }
+                                return super.visitMethodInvocation(node, p);
+                            }
+
+                        }.scan(cut, null);
+                    }
+                    for (Unit source : suspiciousMethodInvocation) {
+                        for (Snippet dep : state.maps.snippetList()) {
+                            if (dep != source.snippet() && dep.status().isActive() &&
+                                dep.kind() == Kind.METHOD &&
+                                source.snippet().kind() == Kind.METHOD &&
+                                dep.name().equals(source.snippet().name())) {
+                                overloads.add(new Unit(state, dep, source.snippet(), new DiagList()));
+                            }
+                        }
+                    }
+                    return null;
+                });
+
+                if (ins.addAll(overloads)) {
+                    ins.stream().forEach(Unit::initialize);
+                    ins.stream().forEach(u -> u.setWrap(ins, ins));
+                }
+            }
+
             state.taskFactory.analyze(outerWrapSet(ins), at -> {
                 ins.stream().forEach(u -> u.setDiagnostics(at));
 
@@ -994,7 +1078,7 @@ class Eval {
             while (true) {
                 List<Unit> legit = ins.stream()
                         .filter(Unit::isDefined)
-                        .collect(toList());
+                        .toList();
                 state.debug(DBG_GEN, "compileAndLoad ins = %s -- legit = %s\n",
                         ins, legit);
                 if (legit.isEmpty()) {
@@ -1026,7 +1110,7 @@ class Eval {
                         // attempt to redefine the remaining classes
                         List<Unit> toReplace = legit.stream()
                                 .filter(u -> !u.doRedefines())
-                                .collect(toList());
+                                .toList();
 
                         // prevent alternating redefine/replace cyclic dependency
                         // loop by replacing all that have been replaced
@@ -1053,7 +1137,7 @@ class Eval {
             // add any new dependencies to the working set
             List<Unit> newDependencies = ins.stream()
                     .flatMap(Unit::effectedDependents)
-                    .collect(toList());
+                    .toList();
             state.debug(DBG_GEN, "compileAndLoad %s -- deps: %s  success: %s\n",
                     ins, newDependencies, success);
             if (!ins.addAll(newDependencies) && success) {
@@ -1227,6 +1311,9 @@ class Eval {
                     fatal = true;
                     break;
                 case ABSTRACT:
+                    // for classes, abstract is valid
+                    // for variables, generate an error message
+                    // for methods, we generate a placeholder method
                     if (isAbstractProhibited) {
                         list.add(mod);
                         fatal = true;
@@ -1237,9 +1324,12 @@ class Eval {
                 case PRIVATE:
                     // quietly ignore, user cannot see effects one way or the other
                     break;
-                case STATIC:
                 case FINAL:
-                    list.add(mod);
+                    //OK to declare an element final
+                    //final classes needed for sealed classes
+                    break;
+                case STATIC:
+                    // everything is static -- warning just adds noise when pasting
                     break;
             }
         }
