@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,15 +150,19 @@ public class FormatData_nl extends ListResourceBundle {
                "K3",
                "K4",
             };
-        final String[] metaValue_QuarterNarrows = new String[] {
-               "1",
-               "2",
-               "3",
-               "4",
-            };
         final String[] metaValue_AmPmMarkers = new String[] {
                "a.m.",
                "p.m.",
+               "middernacht",
+               "",
+               "\u2019s ochtends",
+               "",
+               "\u2019s middags",
+               "",
+               "\u2019s avonds",
+               "",
+               "\u2019s nachts",
+               "",
             };
         final String[] metaValue_TimePatterns = new String[] {
                "HH:mm:ss zzzz",
@@ -176,6 +176,12 @@ public class FormatData_nl extends ListResourceBundle {
                "{1} {0}",
                "{1} {0}",
             };
+        final String[] metaValue_buddhist_QuarterNarrows = new String[] {
+               "1",
+               "2",
+               "3",
+               "4",
+            };
         final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BE",
@@ -247,6 +253,8 @@ public class FormatData_nl extends ListResourceBundle {
                "\u2030",
                "\u221e",
                "NaN",
+               "",
+               "",
             };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
@@ -268,6 +276,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "calendarname.islamic-civil", "Islamitische kalender (cyclisch)" },
@@ -284,6 +294,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "gonm.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -301,6 +313,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNames", metaValue_MonthNames },
@@ -324,6 +338,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.minute", "minuut" },
@@ -343,6 +359,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.MonthNames",
@@ -362,7 +380,7 @@ public class FormatData_nl extends ListResourceBundle {
                     "",
                 }
             },
-            { "japanese.QuarterNarrows", metaValue_QuarterNarrows },
+            { "japanese.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "saur.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "arab.NumberElements",
                 new String[] {
@@ -377,6 +395,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "beng.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -396,6 +416,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -403,27 +425,11 @@ public class FormatData_nl extends ListResourceBundle {
             { "sund.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "arabext.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.second", "seconde" },
-            { "islamic.MonthNarrows",
-                new String[] {
-                    "1",
-                    "2",
-                    "3",
-                    "4",
-                    "5",
-                    "6",
-                    "7",
-                    "8",
-                    "9",
-                    "10",
-                    "11",
-                    "12",
-                    "",
-                }
-            },
             { "vaii.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Islamitische kalender" },
             { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "DayPeriodRules", "midnight:00:00;night1:00:00-06:00;afternoon1:12:00-18:00;morning1:06:00-12:00;evening1:18:00-24:00" },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "brah.NumberElements", metaValue_brah_NumberElements },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -442,6 +448,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.MonthNarrows", metaValue_MonthNarrows },
@@ -464,6 +472,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
@@ -481,6 +491,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "TimePatterns", metaValue_TimePatterns },
@@ -500,6 +512,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "sund.NumberElements",
@@ -515,6 +529,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "telu.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -532,10 +548,11 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNames", metaValue_DayNames },
-            { "QuarterNarrows", metaValue_QuarterNarrows },
             { "lanatham.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
@@ -559,6 +576,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "cakm.NumberElements", metaValue_brah_NumberElements },
@@ -575,6 +594,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "DayNames", metaValue_DayNames },
@@ -596,6 +617,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
@@ -612,6 +635,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.DayNarrows", metaValue_DayNarrows },
@@ -646,6 +671,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "QuarterAbbreviations", metaValue_QuarterAbbreviations },
@@ -665,6 +692,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u0609",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
@@ -689,6 +718,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.TimePatterns", metaValue_TimePatterns },
@@ -713,6 +744,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -732,6 +765,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "long.Eras",
@@ -740,7 +775,7 @@ public class FormatData_nl extends ListResourceBundle {
                     "na Christus",
                 }
             },
-            { "roc.QuarterNarrows", metaValue_QuarterNarrows },
+            { "roc.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "saur.NumberElements",
                 new String[] {
                     ",",
@@ -754,6 +789,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.MonthNames", metaValue_MonthNames },
@@ -787,6 +824,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "bali.NumberElements",
@@ -802,6 +841,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
@@ -826,8 +867,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "{one:000' 'biljoen other:000' 'biljoen}",
                 }
             },
-            { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_AmPmMarkers },
+            { "buddhist.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "standalone.QuarterNames", metaValue_QuarterNames },
             { "standalone.DayNarrows", metaValue_DayNarrows },
             { "mlym.NumberElements",
@@ -843,6 +884,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "lepc.NumberElements",
@@ -858,6 +901,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "gujr.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -874,6 +919,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "limb.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -891,6 +938,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "field.zone", "tijdzone" },
@@ -917,6 +966,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
@@ -939,6 +990,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "lepc.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -959,6 +1012,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
@@ -982,6 +1037,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "olck.NumberPatterns", metaValue_arabext_NumberPatterns },
@@ -1001,6 +1058,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
@@ -1008,7 +1067,7 @@ public class FormatData_nl extends ListResourceBundle {
             { "talu.NumberPatterns", metaValue_arabext_NumberPatterns },
             { "field.week", "week" },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
-            { "islamic.QuarterNarrows", metaValue_QuarterNarrows },
+            { "islamic.QuarterNarrows", metaValue_buddhist_QuarterNarrows },
             { "orya.NumberElements",
                 new String[] {
                     ",",
@@ -1022,6 +1081,8 @@ public class FormatData_nl extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
@@ -1048,6 +1109,7 @@ public class FormatData_nl extends ListResourceBundle {
             },
             { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
             { "cham.NumberPatterns", metaValue_arabext_NumberPatterns },
+            { "PluralRules", "one:i = 1 and v = 0" },
             { "field.hour", "uur" },
             { "islamic.MonthAbbreviations",
                 new String[] {
